@@ -6,16 +6,22 @@ EXTENSIONS = {
     'asciidoc': {'text', 'asciidoc'},
     'apinotes': {'text', 'apinotes'},
     'asar': {'binary', 'asar'},
+    'asm': {'text', 'asm'},
+    'astro': {'text', 'astro'},
     'avif': {'binary', 'image', 'avif'},
     'avsc': {'text', 'avro-schema'},
     'bash': {'text', 'shell', 'bash'},
     'bat': {'text', 'batch'},
     'bats': {'text', 'shell', 'bash', 'bats'},
     'bazel': {'text', 'bazel'},
+    'bb': {'text', 'bitbake'},
+    'bbappend': {'text', 'bitbake'},
+    'bbclass': {'text', 'bitbake'},
     'beancount': {'text', 'beancount'},
     'bib': {'text', 'bib'},
     'bmp': {'binary', 'image', 'bitmap'},
     'bz2': {'binary', 'bzip2'},
+    'bz3': {'binary', 'bzip3'},
     'bzl': {'text', 'bazel'},
     'c': {'text', 'c'},
     'c++': {'text', 'c++'},
@@ -37,11 +43,12 @@ EXTENSIONS = {
     'cr': {'text', 'crystal'},
     'crt': {'text', 'pem'},
     'cs': {'text', 'c#'},
-    'csproj': {'text', 'xml', 'csproj'},
+    'csproj': {'text', 'xml', 'csproj', 'msbuild'},
     'csh': {'text', 'shell', 'csh'},
     'cson': {'text', 'cson'},
     'css': {'text', 'css'},
     'csv': {'text', 'csv'},
+    'csx': {'text', 'c#', 'c#script'},
     'cu': {'text', 'cuda'},
     'cue': {'text', 'cue'},
     'cuh': {'text', 'cuda'},
@@ -56,6 +63,8 @@ EXTENSIONS = {
     'ear': {'binary', 'zip', 'jar'},
     'edn': {'text', 'clojure', 'edn'},
     'ejs': {'text', 'ejs'},
+    'ejson': {'text', 'json', 'ejson'},
+    'elm': {'text', 'elm'},
     'env': {'text', 'dotenv'},
     'eot': {'binary', 'eot'},
     'eps': {'binary', 'eps'},
@@ -72,11 +81,15 @@ EXTENSIONS = {
     'feature': {'text', 'gherkin'},
     'fish': {'text', 'fish'},
     'fits': {'binary', 'fits'},
+    'fs': {'text', 'f#'},
+    'fsproj': {'text', 'xml', 'fsproj', 'msbuild'},
+    'fsx': {'text', 'f#', 'f#script'},
     'gd': {'text', 'gdscript'},
     'gemspec': {'text', 'ruby'},
     'geojson': {'text', 'geojson', 'json'},
     'ggb': {'binary', 'zip', 'ggb'},
     'gif': {'binary', 'image', 'gif'},
+    'gleam': {'text', 'gleam'},
     'go': {'text', 'go'},
     'gotmpl': {'text', 'gotmpl'},
     'gpx': {'text', 'gpx', 'xml'},
@@ -144,6 +157,7 @@ EXTENSIONS = {
     'lua': {'text', 'lua'},
     'm': {'text', 'objective-c'},
     'm4': {'text', 'm4'},
+    'magik': {'text', 'magik'},
     'make': {'text', 'makefile'},
     'manifest': {'text', 'manifest'},
     'map': {'text', 'map'},
@@ -188,8 +202,11 @@ EXTENSIONS = {
     'pp': {'text', 'puppet'},
     'prisma': {'text', 'prisma'},
     'properties': {'text', 'java-properties'},
+    'props': {'text', 'xml', 'msbuild'},
     'proto': {'text', 'proto'},
     'ps1': {'text', 'powershell'},
+    'psd1': {'text', 'powershell'},
+    'psm1': {'text', 'powershell'},
     'pug': {'text', 'pug'},
     'puml': {'text', 'plantuml'},
     'purs': {'text', 'purescript'},
@@ -197,7 +214,7 @@ EXTENSIONS = {
     'pxi': {'text', 'cython'},
     'py': {'text', 'python'},
     'pyi': {'text', 'pyi'},
-    'pyproj': {'text', 'xml', 'pyproj'},
+    'pyproj': {'text', 'xml', 'pyproj', 'msbuild'},
     'pyt': {'text', 'python'},
     'pyx': {'text', 'cython'},
     'pyz': {'binary', 'pyz'},
@@ -211,6 +228,7 @@ EXTENSIONS = {
     'rs': {'text', 'rust'},
     'rst': {'text', 'rst'},
     's': {'text', 'asm'},
+    'sas': {'text', 'sas'},
     'sass': {'text', 'sass'},
     'sbt': {'text', 'sbt', 'scala'},
     'sc': {'text', 'scala'},
@@ -236,6 +254,8 @@ EXTENSIONS = {
     'swiftdeps': {'text', 'swiftdeps'},
     'tac': {'text', 'twisted', 'python'},
     'tar': {'binary', 'tar'},
+    'targets': {'text', 'xml', 'msbuild'},
+    'templ': {'text', 'templ'},
     'tex': {'text', 'tex'},
     'textproto': {'text', 'textproto'},
     'tf': {'text', 'terraform'},
@@ -255,8 +275,8 @@ EXTENSIONS = {
     'urdf': {'text', 'xml', 'urdf'},
     'v': {'text', 'verilog'},
     'vb': {'text', 'vb'},
-    'vbproj': {'text', 'xml', 'vbproj'},
-    'vcxproj': {'text', 'xml', 'vcxproj'},
+    'vbproj': {'text', 'xml', 'vbproj', 'msbuild'},
+    'vcxproj': {'text', 'xml', 'vcxproj', 'msbuild'},
     'vdx': {'text', 'vdx'},
     'vh': {'text', 'verilog'},
     'vhd': {'text', 'vhdl'},
@@ -270,6 +290,7 @@ EXTENSIONS = {
     'wkt': {'text', 'wkt'},
     'woff': {'binary', 'woff'},
     'woff2': {'binary', 'woff2'},
+    'wsdl': {'text', 'xml', 'wsdl'},
     'wsgi': {'text', 'wsgi', 'python'},
     'xhtml': {'text', 'xml', 'html', 'xhtml'},
     'xacro': {'text', 'xml', 'urdf', 'xacro'},
@@ -283,6 +304,7 @@ EXTENSIONS = {
     'xqy': {'text', 'xquery'},
     'xsd': {'text', 'xml', 'xsd'},
     'xsl': {'text', 'xml', 'xsl'},
+    'xslt': {'text', 'xml', 'xsl'},
     'yaml': {'text', 'yaml'},
     'yamlld': {'text', 'yaml', 'yamlld'},
     'yang': {'text', 'yang'},
@@ -316,6 +338,7 @@ NAMES = {
     '.csslintrc': EXTENSIONS['json'] | {'csslintrc'},
     '.dockerignore': {'text', 'dockerignore'},
     '.editorconfig': {'text', 'editorconfig'},
+    '.envrc': EXTENSIONS['bash'],
     '.flake8': EXTENSIONS['ini'] | {'flake8'},
     '.gitattributes': {'text', 'gitattributes'},
     '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
@@ -333,6 +356,7 @@ NAMES = {
     '.pypirc': EXTENSIONS['ini'] | {'pypirc'},
     '.rstcheck.cfg': EXTENSIONS['ini'],
     '.salt-lint': EXTENSIONS['yaml'] | {'salt-lint'},
+    '.sqlfluff': EXTENSIONS['ini'],
     '.yamllint': EXTENSIONS['yaml'] | {'yamllint'},
     '.zlogin': EXTENSIONS['zsh'],
     '.zlogout': EXTENSIONS['zsh'],
@@ -340,7 +364,11 @@ NAMES = {
     '.zshrc': EXTENSIONS['zsh'],
     '.zshenv': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
+    'bblayers.conf': EXTENSIONS['bb'],
+    'bitbake.conf': EXTENSIONS['bb'],
     'BUILD': EXTENSIONS['bzl'],
+    'Cargo.toml': EXTENSIONS['toml'] | {'cargo'},
+    'Cargo.lock': EXTENSIONS['toml'] | {'cargo-lock'},
     'CMakeLists.txt': EXTENSIONS['cmake'],
     'CHANGELOG': EXTENSIONS['txt'],
     'config.ru': EXTENSIONS['rb'],
@@ -349,6 +377,7 @@ NAMES = {
     'copy.bara.sky': EXTENSIONS['bzl'],
     'COPYING': EXTENSIONS['txt'],
     'Dockerfile': {'text', 'dockerfile'},
+    'direnvrc': EXTENSIONS['bash'],
     'Gemfile': EXTENSIONS['rb'],
     'Gemfile.lock': {'text'},
     'GNUmakefile': EXTENSIONS['mk'],
@@ -376,6 +405,7 @@ NAMES = {
     'setup.cfg': EXTENSIONS['ini'],
     'sys.config': EXTENSIONS['erl'],
     'sys.config.src': EXTENSIONS['erl'],
+    'Tiltfile': {'text', 'tiltfile'},
     'Vagrantfile': EXTENSIONS['rb'],
     'WORKSPACE': EXTENSIONS['bzl'],
     'wscript': EXTENSIONS['py'],
